.. _about_author:

About the Author
------------------------------------------------------------------------------
::

   (\ (\
   ( -.-)o    I am a lovely Rabbit!
   o_(")(")

**Sanhe Hu** is a very active **Python Developer** Since 2010. Now working at `Whiskerlabs <https://www.whiskerlabs.com/>`_ as a **Data Scientist**. Research area includes **Machine Learning, Big Data Infrastructure, Block Chain, Business Intelligent, Open Cloud, Distribute System**. Love photography, vocal, outdoor, arts, game, and also the best `Python <https://www.python.org/>`_.

- My Github: https://github.com/MacHu-GWU
- My HomePage: http://www.sanhehu.org/